// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
"use strict";
/**
 * Extract the entry point plugins of a JupyterLab extension.
 *
 * @param data - The loaded entry point module.
 *
 * @returns An array of validated plugins.
 *
 * #### Notes
 * The plugin(s) are extracted and validated before being returned.
 */
function extractPlugins(data) {
    // We use the default export from es6 modules.
    if (data.__esModule) {
        data = data.default;
    }
    if (!Array.isArray(data)) {
        data = [data];
    }
    if (!data.length) {
        throw new Error("No plugins found");
    }
    for (var i = 0; i < data.length; i++) {
        var plugin = data[i];
        if (!plugin.hasOwnProperty('id')) {
            throw new Error("Missing id for plugin " + i);
        }
        if (typeof (plugin['activate']) !== 'function') {
            var id = plugin.id;
            throw Error("Missing activate function in '" + id + "'");
        }
    }
    return data;
}
exports.extractPlugins = extractPlugins;
